@@ -196,7 +196,13 @@ setMethod("codebookEntry","ANY",function(x,weights,unweighted=TRUE,...){
   )
 })
 
-
+rwnexp <- function(mat,nms){
+  res <- array(0,c(length(nms),ncol(mat)),
+               dimnames=list(nms,colnames(mat)))
+  rn <- rownames(mat)
+  res[rn,] <- mat
+  return(res)
+}
 
 codebookTable_factor <- function(x,weights=NULL,...){
 
@@ -205,7 +211,9 @@ codebookTable_factor <- function(x,weights=NULL,...){
 
   isna <- is.na(x)
   counts <- rowsum(weights[!isna],x[!isna])
-
+  lev <- levels(x)
+  counts <- rwnexp(counts,lev)
+  
   NAs <- sum(weights*isna)
 
   tab <- cbind(counts,100*counts/sum(counts))
@@ -576,11 +584,13 @@ setMethod("format","codebookEntry",
     }
     tab <- paste("  ",apply(tab,1,paste,collapse=" "))
   }
+  if(!is.matrix(descr)) descr <- NULL
   if(length(descr)){
     descr.rn <- format(paste(rownames(descr),":",sep=""),justify="right")
     if(is.numeric(descr[]))  
        descr[] <- formatC(descr[],format="f",digits=3)
     descr[] <- gsub("NA","",descr[])
+    if(!length(ncol(descr))) browser()
     if(ncol(descr) > 1){
       descr.rn <- c("","",descr.rn)
       descr <- rbind(colnames(descr),"",descr)
@@ -598,6 +608,8 @@ setMethod("format","codebookEntry",
   else if(length(descr)){
     statstab <- descr
   }
+  else
+    statstab <- NULL
   
   annot.out <- character()
   if(length(annot)){
